==> kubernetes-model-autoscaling-5.0.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ObjectMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ObjectMetricSourceFluentImpl<A extends ObjectMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ObjectMetricSourceFluent<A> {

    private Quantity averageValue;
    private String metricName;
    private LabelSelectorBuilder selector;
    private io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder target;
    private Quantity targetValue;

    public ObjectMetricSourceFluentImpl() {
    }

    public ObjectMetricSourceFluentImpl(ObjectMetricSource instance) {
        this.withAverageValue(instance.getAverageValue()); 
        this.withMetricName(instance.getMetricName()); 
        this.withSelector(instance.getSelector()); 
        this.withTarget(instance.getTarget()); 
        this.withTargetValue(instance.getTargetValue()); 
    }

    public Quantity getAverageValue() {
        return this.averageValue;
    }

    public A withAverageValue(Quantity averageValue) {
        this.averageValue=averageValue; return (A) this;
    }

    public Boolean hasAverageValue() {
        return this.averageValue != null;
    }

    public A withNewAverageValue(String amount,String format) {
        return (A)withAverageValue(new Quantity(amount, format));
    }

    public A withNewAverageValue(String amount) {
        return (A)withAverageValue(new Quantity(amount));
    }

    public String getMetricName() {
        return this.metricName;
    }

    public A withMetricName(String metricName) {
        this.metricName=metricName; return (A) this;
    }

    public Boolean hasMetricName() {
        return this.metricName != null;
    }

    public A withNewMetricName(String arg1) {
        return (A)withMetricName(new String(arg1));
    }

    public A withNewMetricName(StringBuilder arg1) {
        return (A)withMetricName(new String(arg1));
    }

    public A withNewMetricName(StringBuffer arg1) {
        return (A)withMetricName(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public LabelSelector buildSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public A withSelector(LabelSelector selector) {
        _visitables.get("selector").remove(this.selector);
        if (selector!=null){ this.selector= new LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
    }

    public Boolean hasSelector() {
        return this.selector != null;
    }

    public ObjectMetricSourceFluent.SelectorNested<A> withNewSelector() {
        return new SelectorNestedImpl();
    }

    public ObjectMetricSourceFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item) {
        return new SelectorNestedImpl(item);
    }

    public ObjectMetricSourceFluent.SelectorNested<A> editSelector() {
        return withNewSelectorLike(getSelector());
    }

    public ObjectMetricSourceFluent.SelectorNested<A> editOrNewSelector() {
        return withNewSelectorLike(getSelector() != null ? getSelector(): new LabelSelectorBuilder().build());
    }

    public ObjectMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item) {
        return withNewSelectorLike(getSelector() != null ? getSelector(): item);
    }

    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference getTarget() {
        return this.target!=null?this.target.build():null;
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference buildTarget() {
        return this.target!=null?this.target.build():null;
    }

    public A withTarget(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference target) {
        _visitables.get("target").remove(this.target);
        if (target!=null){ this.target= new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
    }

    public Boolean hasTarget() {
        return this.target != null;
    }

    public A withNewTarget(String apiVersion,String kind,String name) {
        return (A)withTarget(new CrossVersionObjectReference(apiVersion, kind, name));
    }

    public ObjectMetricSourceFluent.TargetNested<A> withNewTarget() {
        return new TargetNestedImpl();
    }

    public ObjectMetricSourceFluent.TargetNested<A> withNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference item) {
        return new TargetNestedImpl(item);
    }

    public ObjectMetricSourceFluent.TargetNested<A> editTarget() {
        return withNewTargetLike(getTarget());
    }

    public ObjectMetricSourceFluent.TargetNested<A> editOrNewTarget() {
        return withNewTargetLike(getTarget() != null ? getTarget(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder().build());
    }

    public ObjectMetricSourceFluent.TargetNested<A> editOrNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference item) {
        return withNewTargetLike(getTarget() != null ? getTarget(): item);
    }

    public Quantity getTargetValue() {
        return this.targetValue;
    }

    public A withTargetValue(Quantity targetValue) {
        this.targetValue=targetValue; return (A) this;
    }

    public Boolean hasTargetValue() {
        return this.targetValue != null;
    }

    public A withNewTargetValue(String amount,String format) {
        return (A)withTargetValue(new Quantity(amount, format));
    }

    public A withNewTargetValue(String amount) {
        return (A)withTargetValue(new Quantity(amount));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ObjectMetricSourceFluentImpl that = (ObjectMetricSourceFluentImpl) o;
        if (averageValue != null ? !averageValue.equals(that.averageValue) :that.averageValue != null) return false;
        if (metricName != null ? !metricName.equals(that.metricName) :that.metricName != null) return false;
        if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
        if (target != null ? !target.equals(that.target) :that.target != null) return false;
        if (targetValue != null ? !targetValue.equals(that.targetValue) :that.targetValue != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(averageValue,  metricName,  selector,  target,  targetValue,  super.hashCode());
    }

    public class SelectorNestedImpl<N> extends LabelSelectorFluentImpl<ObjectMetricSourceFluent.SelectorNested<N>> implements ObjectMetricSourceFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final LabelSelectorBuilder builder;

            SelectorNestedImpl(LabelSelector item) {
                this.builder = new LabelSelectorBuilder(this, item);
                        
            }

            SelectorNestedImpl() {
                this.builder = new LabelSelectorBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withSelector(builder.build());
            }

            public N endSelector() {
                return and();
            }
    }


    public class TargetNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceFluentImpl<ObjectMetricSourceFluent.TargetNested<N>> implements ObjectMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder builder;

            TargetNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference item) {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder(this, item);
                        
            }

            TargetNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withTarget(builder.build());
            }

            public N endTarget() {
                return and();
            }
    }


}

==> kubernetes-model-autoscaling-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta1/ObjectMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ObjectMetricSourceFluentImpl<A extends ObjectMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ObjectMetricSourceFluent<A> {

    private Quantity averageValue;
    private String metricName;
    private LabelSelectorBuilder selector;
    private io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder target;
    private Quantity targetValue;

    public ObjectMetricSourceFluentImpl() {
    }

    public ObjectMetricSourceFluentImpl(ObjectMetricSource instance) {
        this.withAverageValue(instance.getAverageValue()); 
        this.withMetricName(instance.getMetricName()); 
        this.withSelector(instance.getSelector()); 
        this.withTarget(instance.getTarget()); 
        this.withTargetValue(instance.getTargetValue()); 
    }

    public Quantity getAverageValue() {
        return this.averageValue;
    }

    public A withAverageValue(Quantity averageValue) {
        this.averageValue=averageValue; return (A) this;
    }

    public Boolean hasAverageValue() {
        return this.averageValue != null;
    }

    public A withNewAverageValue(String amount) {
        return (A)withAverageValue(new Quantity(amount));
    }

    public A withNewAverageValue(String amount,String format) {
        return (A)withAverageValue(new Quantity(amount, format));
    }

    public String getMetricName() {
        return this.metricName;
    }

    public A withMetricName(String metricName) {
        this.metricName=metricName; return (A) this;
    }

    public Boolean hasMetricName() {
        return this.metricName != null;
    }

    public A withNewMetricName(StringBuilder arg1) {
        return (A)withMetricName(new String(arg1));
    }

    public A withNewMetricName(int[] arg1,int arg2,int arg3) {
        return (A)withMetricName(new String(arg1, arg2, arg3));
    }

    public A withNewMetricName(char[] arg1) {
        return (A)withMetricName(new String(arg1));
    }

    public A withNewMetricName(StringBuffer arg1) {
        return (A)withMetricName(new String(arg1));
    }

    public A withNewMetricName(byte[] arg1,int arg2) {
        return (A)withMetricName(new String(arg1, arg2));
    }

    public A withNewMetricName(byte[] arg1) {
        return (A)withMetricName(new String(arg1));
    }

    public A withNewMetricName(char[] arg1,int arg2,int arg3) {
        return (A)withMetricName(new String(arg1, arg2, arg3));
    }

    public A withNewMetricName(byte[] arg1,int arg2,int arg3) {
        return (A)withMetricName(new String(arg1, arg2, arg3));
    }

    public A withNewMetricName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMetricName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMetricName(String arg1) {
        return (A)withMetricName(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public LabelSelector buildSelector() {
        return this.selector!=null?this.selector.build():null;
    }

    public A withSelector(LabelSelector selector) {
        _visitables.get("selector").remove(this.selector);
        if (selector!=null){ this.selector= new LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
    }

    public Boolean hasSelector() {
        return this.selector != null;
    }

    public ObjectMetricSourceFluent.SelectorNested<A> withNewSelector() {
        return new SelectorNestedImpl();
    }

    public ObjectMetricSourceFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item) {
        return new SelectorNestedImpl(item);
    }

    public ObjectMetricSourceFluent.SelectorNested<A> editSelector() {
        return withNewSelectorLike(getSelector());
    }

    public ObjectMetricSourceFluent.SelectorNested<A> editOrNewSelector() {
        return withNewSelectorLike(getSelector() != null ? getSelector(): new LabelSelectorBuilder().build());
    }

    public ObjectMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item) {
        return withNewSelectorLike(getSelector() != null ? getSelector(): item);
    }

    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference getTarget() {
        return this.target!=null?this.target.build():null;
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference buildTarget() {
        return this.target!=null?this.target.build():null;
    }

    public A withTarget(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference target) {
        _visitables.get("target").remove(this.target);
        if (target!=null){ this.target= new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
    }

    public Boolean hasTarget() {
        return this.target != null;
    }

    public A withNewTarget(String apiVersion,String kind,String name) {
        return (A)withTarget(new CrossVersionObjectReference(apiVersion, kind, name));
    }

    public ObjectMetricSourceFluent.TargetNested<A> withNewTarget() {
        return new TargetNestedImpl();
    }

    public ObjectMetricSourceFluent.TargetNested<A> withNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference item) {
        return new TargetNestedImpl(item);
    }

    public ObjectMetricSourceFluent.TargetNested<A> editTarget() {
        return withNewTargetLike(getTarget());
    }

    public ObjectMetricSourceFluent.TargetNested<A> editOrNewTarget() {
        return withNewTargetLike(getTarget() != null ? getTarget(): new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder().build());
    }

    public ObjectMetricSourceFluent.TargetNested<A> editOrNewTargetLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference item) {
        return withNewTargetLike(getTarget() != null ? getTarget(): item);
    }

    public Quantity getTargetValue() {
        return this.targetValue;
    }

    public A withTargetValue(Quantity targetValue) {
        this.targetValue=targetValue; return (A) this;
    }

    public Boolean hasTargetValue() {
        return this.targetValue != null;
    }

    public A withNewTargetValue(String amount) {
        return (A)withTargetValue(new Quantity(amount));
    }

    public A withNewTargetValue(String amount,String format) {
        return (A)withTargetValue(new Quantity(amount, format));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ObjectMetricSourceFluentImpl that = (ObjectMetricSourceFluentImpl) o;
        if (averageValue != null ? !averageValue.equals(that.averageValue) :that.averageValue != null) return false;
        if (metricName != null ? !metricName.equals(that.metricName) :that.metricName != null) return false;
        if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
        if (target != null ? !target.equals(that.target) :that.target != null) return false;
        if (targetValue != null ? !targetValue.equals(that.targetValue) :that.targetValue != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(averageValue,  metricName,  selector,  target,  targetValue,  super.hashCode());
    }

    public class SelectorNestedImpl<N> extends LabelSelectorFluentImpl<ObjectMetricSourceFluent.SelectorNested<N>> implements ObjectMetricSourceFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final LabelSelectorBuilder builder;

            SelectorNestedImpl(LabelSelector item) {
                this.builder = new LabelSelectorBuilder(this, item);
                        
            }

            SelectorNestedImpl() {
                this.builder = new LabelSelectorBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withSelector(builder.build());
            }

            public N endSelector() {
                return and();
            }
    }


    public class TargetNestedImpl<N> extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceFluentImpl<ObjectMetricSourceFluent.TargetNested<N>> implements ObjectMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder builder;

            TargetNestedImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReference item) {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder(this, item);
                        
            }

            TargetNestedImpl() {
                this.builder = new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.CrossVersionObjectReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) ObjectMetricSourceFluentImpl.this.withTarget(builder.build());
            }

            public N endTarget() {
                return and();
            }
    }


}
